==> zio-aws-lexmodelsv2_3-5.17.130.3-sources.jar: zio/aws/lexmodelsv2/model/BotFilterOperator.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters.*
sealed trait BotFilterOperator {
  def unwrap
      : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator
}
object BotFilterOperator {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator
  ): zio.aws.lexmodelsv2.model.BotFilterOperator = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.CO =>
      val r = CO
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.EQ =>
      val r = EQ
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.UNKNOWN_TO_SDK_VERSION
  }
  case object CO extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.CO
  }
  case object EQ extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.EQ
  }
}

==> zio-aws-lexmodelsv2_3-6.20.162.2-sources.jar: zio/aws/lexmodelsv2/model/BotFilterOperator.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters.*
sealed trait BotFilterOperator {
  def unwrap
      : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator
}
object BotFilterOperator {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator
  ): zio.aws.lexmodelsv2.model.BotFilterOperator = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.CO =>
      val r = CO
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.EQ =>
      val r = EQ
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.NE =>
      val r = NE
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.UNKNOWN_TO_SDK_VERSION
  }
  case object CO extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.CO
  }
  case object EQ extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.EQ
  }
  case object NE extends zio.aws.lexmodelsv2.model.BotFilterOperator {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator =
      software.amazon.awssdk.services.lexmodelsv2.model.BotFilterOperator.NE
  }
}
